@@ -5,67 +5,67 @@
 #' statistics, effect size measures, and a plot showing error bars for
 #' difference-adjusted confidence intervals with jittered data points.
 #'
-#' @param formula       a formula of the form \code{y ~ group} where \code{y} is
-#'                      a numeric variable giving the data values and \code{group}
-#'                      a numeric variable, character variable or factor with more
-#'                      than two values or factor levels giving the corresponding
-#'                      groups.
-#' @param data          a matrix or data frame containing the variables in the
-#'                      formula \code{formula}.
-#' @param posthoc       logical: if \code{TRUE}, Tukey HSD post hoc test for
-#'                      multiple comparison is conducted.
-#' @param conf.level    a numeric value between 0 and 1 indicating the confidence
-#'                      level of the interval.
-#' @param hypo          logical: if \code{TRUE} (default), null and alternative
-#'                      hypothesis are shown on the console.
-#' @param descript      logical: if \code{TRUE} (default), descriptive statistics
-#'                      are shown on the console.
-#' @param effsize       logical: if \code{TRUE}, effect size measures \eqn{\eta^2}
-#'                      and \eqn{\omega^2} for the ANOVA and Cohen's d for the post
-#'                      hoc tests are shown on the console.
-#' @param weighted      logical: if \code{TRUE}, the weighted pooled standard
-#'                      deviation is used to compute Cohen's d.
-#' @param correct       logical: if \code{TRUE}, correction factor to remove
-#'                      positive bias in small samples is used.
-#' @param plot          logical: if \code{TRUE}, a plot showing error bars for
-#'                      confidence intervals is drawn.
-#' @param point.size    a numeric value indicating the \code{size} aesthetic for
-#'                      the point representing the mean value.
-#' @param adjust        logical: if \code{TRUE} (default), difference-adjustment
-#'                      for the confidence intervals is applied.
-#' @param error.width   a numeric value indicating the horizontal bar width of
-#'                      the error bar.
-#' @param xlab          a character string specifying the labels for the x-axis.
-#' @param ylab          a character string specifying the labels for the y-axis.
-#' @param ylim          a numeric vector of length two specifying limits of the
-#'                      limits of the y-axis.
-#' @param breaks        a numeric vector specifying the points at which tick-marks
-#'                      are drawn at the y-axis.
-#' @param jitter        logical: if \code{TRUE} (default), jittered data points
-#'                      are drawn.
-#' @param jitter.size   a numeric value indicating the \code{size} aesthetic
-#'                      for the jittered data points.
-#' @param jitter.width  a numeric value indicating the amount of horizontal jitter.
-#' @param jitter.height a numeric value indicating the amount of vertical jitter.
-#' @param jitter.alpha  a numeric value indicating the opacity of the jittered
-#'                      data points.
-#' @param title         a character string specifying the text for the title for
-#'                      the plot.
-#' @param subtitle      a character string specifying the text for the subtitle for
-#'                      the plot.
-#' @param digits        an integer value indicating the number of decimal places
-#'                      to be used for displaying descriptive statistics and
-#'                      confidence interval.
-#' @param p.digits      an integer value indicating the number of decimal places
-#'                      to be used for displaying the \emph{p}-value.
-#' @param as.na         a numeric vector indicating user-defined missing values,
-#'                      i.e. these values are converted to \code{NA} before conducting
-#'                      the analysis.
-#' @param check         logical: if \code{TRUE} (default), argument specification
-#'                      is checked.
-#' @param output        logical: if \code{TRUE} (default), output is shown on the
-#'                      console.
-#' @param ...           further arguments to be passed to or from methods.
+#' @param formula        a formula of the form \code{y ~ group} where \code{y} is
+#'                       a numeric variable giving the data values and \code{group}
+#'                       a numeric variable, character variable or factor with more
+#'                       than two values or factor levels giving the corresponding
+#'                       groups.
+#' @param data           a matrix or data frame containing the variables in the
+#'                       formula \code{formula}.
+#' @param posthoc        logical: if \code{TRUE}, Tukey HSD post hoc test for
+#'                       multiple comparison is conducted.
+#' @param conf.level     a numeric value between 0 and 1 indicating the confidence
+#'                       level of the interval.
+#' @param hypo           logical: if \code{TRUE} (default), null and alternative
+#'                       hypothesis are shown on the console.
+#' @param descript       logical: if \code{TRUE} (default), descriptive statistics
+#'                       are shown on the console.
+#' @param effsize        logical: if \code{TRUE}, effect size measures \eqn{\eta^2}
+#'                       and \eqn{\omega^2} for the ANOVA and Cohen's d for the post
+#'                       hoc tests are shown on the console.
+#' @param weighted       logical: if \code{TRUE}, the weighted pooled standard
+#'                       deviation is used to compute Cohen's d.
+#' @param correct        logical: if \code{TRUE}, correction factor to remove
+#'                       positive bias in small samples is used.
+#' @param plot           logical: if \code{TRUE}, a plot showing error bars for
+#'                       confidence intervals is drawn.
+#' @param point.size     a numeric value indicating the \code{size} aesthetic for
+#'                       the point representing the mean value.
+#' @param adjust         logical: if \code{TRUE} (default), difference-adjustment
+#'                       for the confidence intervals is applied.
+#' @param errorbar.width a numeric value indicating the horizontal bar width of
+#'                       the error bar.
+#' @param xlab           a character string specifying the labels for the x-axis.
+#' @param ylab           a character string specifying the labels for the y-axis.
+#' @param ylim           a numeric vector of length two specifying limits of the
+#'                       limits of the y-axis.
+#' @param breaks         a numeric vector specifying the points at which tick-marks
+#'                       are drawn at the y-axis.
+#' @param jitter         logical: if \code{TRUE} (default), jittered data points
+#'                       are drawn.
+#' @param jitter.size    a numeric value indicating the \code{size} aesthetic
+#'                       for the jittered data points.
+#' @param jitter.width   a numeric value indicating the amount of horizontal jitter.
+#' @param jitter.height  a numeric value indicating the amount of vertical jitter.
+#' @param jitter.alpha   a numeric value indicating the opacity of the jittered
+#'                       data points.
+#' @param title          a character string specifying the text for the title of
+#'                       the plot.
+#' @param subtitle       a character string specifying the text for the subtitle
+#'                       of the plot.
+#' @param digits         an integer value indicating the number of decimal places
+#'                       to be used for displaying descriptive statistics and
+#'                       confidence interval.
+#' @param p.digits       an integer value indicating the number of decimal places
+#'                       to be used for displaying the \emph{p}-value.
+#' @param as.na          a numeric vector indicating user-defined missing values,
+#'                       i.e. these values are converted to \code{NA} before conducting
+#'                       the analysis.
+#' @param check          logical: if \code{TRUE} (default), argument specification
+#'                       is checked.
+#' @param output         logical: if \code{TRUE} (default), output is shown on the
+#'                       console.
+#' @param ...            further arguments to be passed to or from methods.
 #'
 #' @details
 #' \describe{
@@ -118,8 +118,8 @@
 #' \item{\code{type}}{type of analysis}
 #' \item{\code{data}}{data frame with variables used in the current analysis}
 #' \item{\code{formula}}{formula of the current analysis}
-#' \item{\code{plot}}{ggplot2 object for plotting the results}
 #' \item{\code{args}}{specification of function arguments}
+#' \item{\code{plot}}{ggplot2 object for plotting the results}
 #' \item{\code{result}}{result tables}
 #'
 #' @export
@@ -139,7 +139,6 @@
 #' # do not print hypotheses and descriptive statistics,
 #' aov.b(y ~ group, data = dat, descript = FALSE, hypo = FALSE)
 #'
-#' \dontrun{
 #' # Example 4: Write Results into a text file
 #' aov.b(y ~ group, data = dat, write = "ANOVA.txt")
 #'
@@ -167,17 +166,16 @@
 #'   geom_point(stat = "summary", fun = "mean", size = 4) +
 #'   stat_summary(fun.data = "mean_cl_normal", geom = "errorbar", width = 0.20) +
 #'   scale_x_discrete(name = NULL) +
-#'   labs(subtitle = "Two-Sided 95% Confidence Interval") +
+#'   labs(subtitle = "Two-Sided Confidence Interval") +
 #'   theme_bw() + theme(plot.subtitle = element_text(hjust = 0.5))
-#' }
 aov.b <- function(formula, data, posthoc = FALSE, conf.level = 0.95,
                   hypo = TRUE, descript = TRUE, effsize = FALSE, weighted = FALSE,
                   correct = FALSE, plot = FALSE, point.size = 4, adjust = TRUE,
-                  error.width = 0.1, xlab = NULL, ylab = NULL, ylim = NULL,
+                  errorbar.width = 0.1, xlab = NULL, ylab = NULL, ylim = NULL,
                   breaks = ggplot2::waiver(), jitter = TRUE, jitter.size = 1.25,
                   jitter.width = 0.05, jitter.height = 0, jitter.alpha = 0.1,
                   title = "", subtitle = "Confidence Interval",
-                  digits = 2, p.digits = 4, as.na = NULL, write = NULL,
+                  digits = 2, p.digits = 3, as.na = NULL, write = NULL,
                   append = TRUE, check = TRUE, output = TRUE, ...) {
 
   #_____________________________________________________________________________
@@ -212,78 +210,33 @@ aov.b <- function(formula, data, posthoc = FALSE, conf.level = 0.95,
   #
   # Input Check ----------------------------------------------------------------
 
-  # Check input 'check'
-  if (isTRUE(!is.logical(check))) { stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE) }
+  # Check inputs and R package
+  .check.input(logical = c("posthoc", "hypo", "descript", "effsize", "weighted", "correct", "plot", "adjust", "jitter", "append", "output"),
+               numeric = list(point.size = 1L, errorbar.width = 1L, jitter.size = 1L, jitter.width = 1L, jitter.height = 1L, jitter.alpha = 1L),
+               character = list(xlab = 1L, ylab = 1L, title = 1L, subtitle = 1L), args = c("digits", "p.digits", "conf.level", "write1"), package = "ggplot2", envir = environment(), input.check = check)
 
+  # Additional checks
   if (isTRUE(check)) {
 
-    # ggplot2 package
-    if (isTRUE(plot && !nzchar(system.file(package = "ggplot2"))))  { stop("Package \"ggplot2\" is needed for drawing a bar chart, please install the package.", call. = FALSE) }
-
     # Check if variables are in the data
-    var.data <- !var.formula %in% colnames(data)
-    if (isTRUE(any(var.data))) { stop(paste0("Variables specified in the formula were not found in 'data': ", paste(var.formula[which(var.data)], collapse = ", ")), call. = FALSE) }
+    (!var.formula %in% colnames(data)) |>
+      (\(y) if (isTRUE(any(y))) { stop(paste0(ifelse(sum(y) == 1L, "Variable ", "Variables "), "specified in the formula ", ifelse(sum(y) == 1L, "was ", "were "), "not found in 'data': ", paste(var.formula[y], collapse = ", ")), call. = FALSE) })()
 
     # Check if variance in any group is zero
-    y.zero.var <- misty::na.as(c(tapply(data[, y.var], data[, group.var], var, na.rm = TRUE)), na = 0L, check = FALSE) == 0L
-    if (isTRUE(any(y.zero.var))) {
+    misty::na.as(c(tapply(data[, y.var], data[, group.var], var, na.rm = TRUE)), na = 0L, check = FALSE) == 0L |>
+     (\(y) if (isTRUE(any(y))) {
 
-      if (isTRUE(sum(y.zero.var) == 1L)) { stop(paste0("Variance in group \"", names(which(y.zero.var))), "\" is zero.", call. = FALSE) }
+       if (isTRUE(sum(y) == 1L)) { stop(paste0("Variance in group \"", names(which(y))), "\" is zero.", call. = FALSE) }
 
-    } else {
+     } else {
 
-      if (isTRUE(sum(y.zero.var) == 1L)) { stop(paste0("Variance in following groups are zero: ", paste0(names(which(y.zero.var)), collapse = ", ")), call. = FALSE) }
+       if (isTRUE(sum(y) == 1L)) { stop(paste0("Variance in following groups are zero: ", paste0(names(which(y)), collapse = ", ")), call. = FALSE) }
 
-    }
+     })()
 
     # Check if input 'formula' has only one outcome variable
     if (isTRUE(length(y.var) != 1L)) { stop("Please specify a formula with only one outcome variable.", call. = FALSE) }
 
-    # Check input 'posthoc'
-    if (isTRUE(!is.logical(posthoc))) { stop("Please specify TRUE or FALSE for the argument 'posthoc'.", call. = FALSE) }
-
-    # Check input 'conf.level'
-    if (isTRUE(conf.level >= 1L || conf.level <= 0L)) { stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.", call. = FALSE) }
-
-    # Check input 'hypo'
-    if (isTRUE(!is.logical(hypo))) { stop("Please specify TRUE or FALSE for the argument 'hypo'.", call. = FALSE) }
-
-    # Check input 'descript'
-    if (isTRUE(!is.logical(descript))) { stop("Please specify TRUE or FALSE for the argument 'descript'.", call. = FALSE) }
-
-    # Check input 'effsize'
-    if (isTRUE(!is.logical(effsize))) { stop("Please specify TRUE or FALSE for the argument 'effsize'.", call. = FALSE) }
-
-    # Check input 'weighted'
-    if (isTRUE(!is.logical(weighted))) { stop("Please specify TRUE or FALSE for the argument 'weighted'.", call. = FALSE) }
-
-    # Check input 'correct'
-    if (isTRUE(!is.logical(correct))) { stop("Please specify TRUE or FALSE for the argument 'correct'.", call. = FALSE) }
-
-    # Check input 'plot'
-    if (isTRUE(!is.logical(plot))) { stop("Please specify TRUE or FALSE for the argument 'plot'.", call. = FALSE) }
-
-    # Check input 'adjust'
-    if (isTRUE(!is.logical(adjust))) { stop("Please specify TRUE or FALSE for the argument 'adjust'.", call. = FALSE) }
-
-    # Check input 'jitter'
-    if (isTRUE(!is.logical(jitter))) { stop("Please specify TRUE or FALSE for the argument 'jitter'.", call. = FALSE) }
-
-    # Check input 'digits'
-    if (isTRUE(digits %% 1L != 0L || digits < 0L)) { stop("Please specify a positive integer number for the argument 'digits'.", call. = FALSE) }
-
-    # Check input 'p.digits'
-    if (isTRUE(p.digits %% 1L != 0L || p.digits < 0L)) { stop("Please specify a positive integer number for the argument 'p.digits'.", call. = FALSE) }
-
-    # Check input 'write'
-    if (isTRUE(!is.null(write) && substr(write, nchar(write) - 3L, nchar(write)) != ".txt")) { stop("Please specify a character string with file extenstion '.txt' for the argument 'write'.") }
-
-    # Check input 'append'
-    if (isTRUE(!is.logical(append))) { stop("Please specify TRUE or FALSE for the argument 'append'.", call. = FALSE) }
-
-    # Check input 'output'
-    if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
-
   }
 
   #_____________________________________________________________________________
@@ -299,16 +252,16 @@ aov.b <- function(formula, data, posthoc = FALSE, conf.level = 0.95,
     data[, y.var] <- .as.na(data[, y.var], na = as.na)
 
     # Check if variance in any group is zero
-    y.zero.var <- misty::na.as(c(tapply(data[, y.var], data[, group.var], var, na.rm = TRUE)), na = 0, check = FALSE) == 0L
-    if (isTRUE(any(y.zero.var))) {
+    (misty::na.as(c(tapply(data[, y.var], data[, group.var], var, na.rm = TRUE)), na = 0, check = FALSE) == 0L) |>
+      (\(y) if (isTRUE(any(y))) {
 
-      if (isTRUE(sum(y.zero.var) == 1L)) { stop(paste0("After converting user-missing values into NA, variance in group \"", names(which(y.zero.var))), "\" is zero.", call. = FALSE) }
+        if (isTRUE(sum(y) == 1L)) { stop(paste0("After converting user-missing values into NA, variance in group \"", names(which(y))), "\" is zero.", call. = FALSE) }
 
-    } else {
+      } else {
 
-      if (isTRUE(sum(y.zero.var) == 1L)) { stop(paste0("After converting user-missing values into NA, variance in following groups are zero: ", paste0(names(which(y.zero.var)), collapse = ", ")), call. = FALSE) }
+        if (isTRUE(sum(y) == 1L)) { stop(paste0("After converting user-missing values into NA, variance in following groups are zero: ", paste0(names(which(y)), collapse = ", ")), call. = FALSE) }
 
-    }
+      })()
 
   }
 
@@ -328,7 +281,8 @@ aov.b <- function(formula, data, posthoc = FALSE, conf.level = 0.95,
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Descriptive statistics ####
 
-  ci <- misty::ci.mean(y, group = group, adjust = adjust, conf.level = conf.level, output = FALSE)$result[, -c(2L, 5L)]
+  ci <- misty::ci.mean(y, group = group, adjust = adjust, conf.level = conf.level, output = FALSE)$result |>
+    (\(y) data.frame(y[, c("group", "n", "nNA", "m", "low", "upp", "sd", "skew", "kurt")]))()
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Fit ANOVA model ####
@@ -359,8 +313,7 @@ aov.b <- function(formula, data, posthoc = FALSE, conf.level = 0.95,
   #...................
   ### Omega squared ####
 
-  omega.sq <- ((ss.m - df.m*ms.r) / (ss.t + ms.r)) |>
-    (\(y) ifelse(y < 0L, 0L, y))()
+  omega.sq <- ((ss.m - df.m*ms.r) / (ss.t + ms.r)) |> (\(y) ifelse(y < 0L, 0L, y))()
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## ANOVA table ####
@@ -387,21 +340,18 @@ aov.b <- function(formula, data, posthoc = FALSE, conf.level = 0.95,
 
   #...................
   ### Result table ####
-  result.ph <- data.frame(group1 = labels[, 1L], group2 = labels[, 2L], m.diff = result.ph[, "diff"],
-                          m.low = result.ph[, "lwr"], m.upp = result.ph[, "upr"], pval = result.ph[, "p adj"],
-                          row.names = NULL)
+  result.ph <- data.frame(group1 = labels[, 1L], group2 = labels[, 2L], m.diff = result.ph[, "diff"], m.low = result.ph[, "lwr"], m.upp = result.ph[, "upr"], pval = result.ph[, "p adj"], row.names = NULL)
 
   #...................
   ### Cohen's d ####
-  cohen <- t(sapply(1:nrow(result.ph), function(x) {
+  cohen <- t(sapply(seq_len(nrow(result.ph)), function(x) {
 
     data.temp <- data.frame(group, y)[which(group %in% unlist(result.ph[x, c("group1", "group2")])), ]
 
     # Drop factor levels
     data.temp[, "group"] <- droplevels(data.temp[, "group"], except = unlist(result.ph[x, c("group1", "group2")]))
 
-    misty::cohens.d(y ~ group, data = data.temp, weighted = weighted, correct = correct, conf.level = conf.level,
-                    check = FALSE, output = FALSE)$result[2L, c("d", "low", "upp")]
+    misty::cohens.d(y ~ group, data = data.temp, weighted = weighted, correct = correct, conf.level = conf.level, check = FALSE, output = FALSE)$result[2L, c("d", "low", "upp")]
 
   }))
 
@@ -455,7 +405,7 @@ aov.b <- function(formula, data, posthoc = FALSE, conf.level = 0.95,
   if (isTRUE(jitter)) { p <- p + ggplot2::geom_jitter(alpha = jitter.alpha, width = jitter.width, height = jitter.height, size = jitter.size) }
 
   p <- p + ggplot2::geom_point(data = plot.ci, ggplot2::aes(group, m), stat = "identity", size = point.size) +
-         ggplot2::geom_errorbar(data = plot.ci, ggplot2::aes(group, m, ymin = low, ymax = upp), width = error.width) +
+         ggplot2::geom_errorbar(data = plot.ci, ggplot2::aes(group, m, ymin = low, ymax = upp), width = errorbar.width) +
          ggplot2::scale_x_discrete(name = xlab) +
          ggplot2::scale_y_continuous(name = ylab, limits = ylim, breaks = breaks) +
          ggplot2::theme_bw() +
@@ -475,18 +425,17 @@ aov.b <- function(formula, data, posthoc = FALSE, conf.level = 0.95,
                  type = "aov.b",
                  data = data.frame(y, group, stringsAsFactors = FALSE),
                  formula = formula,
-                 plot = p,
                  args = list(posthoc = posthoc, conf.level = conf.level,
                              hypo = hypo, descript = descript, effsize = effsize,
                              weighted = weighted, correct = correct, plot = plot,
-                             point.size = point.size, error.width = error.width,
+                             point.size = point.size, errorbar.width = errorbar.width,
                              xlab = xlab, ylab = ylab, ylim = ylim, breaks = breaks,
                              jitter = jitter, jitter.size = jitter.size, jitter.width = jitter.width,
                              jitter.height = jitter.height, jitter.alpha = jitter.alpha,
                              title = title, subtitle = subtitle, digits = digits,
                              p.digits = p.digits, as.na = as.na, check = check,
                              write = write, append = append, output = output),
-                 result = result)
+                 plot = p, result = result)
 
   class(object) <- "misty.object"
 
@@ -521,3 +470,5 @@ aov.b <- function(formula, data, posthoc = FALSE, conf.level = 0.95,
   return(invisible(object))
 
 }
+
+#_______________________________________________________________________________
