@@ -5,84 +5,84 @@
 #' statistics, effect size measures, and a plot showing error bars for
 #' difference-adjusted confidence intervals with jittered data points.
 #'
-#' @param formula       a formula of the form \code{y ~ group} where \code{y} is
-#'                      a numeric variable giving the data values and \code{group}
-#'                      a numeric variable, character variable or factor with two
-#'                      or more than two values or factor levels giving the
-#'                      corresponding groups.
-#' @param data          a matrix or data frame containing the variables in the
-#'                      formula \code{formula}.
-#' @param alternative   a character string specifying the alternative hypothesis,
-#'                      must be one of \code{"two.sided"} (default), \code{"greater"}
-#'                      or \code{"less"}. Note that this argument is only used when
-#'                      conducting Welch's two-sample t-test.
-#' @param posthoc       logical: if \code{TRUE}, Games-Howell post hoc test for
-#'                      multiple comparison is conducted when performing Welch's
-#'                      ANOVA.
-#' @param conf.level    a numeric value between 0 and 1 indicating the confidence
-#'                      level of the interval.
-#' @param hypo          logical: if \code{TRUE} (default), null and alternative
-#'                      hypothesis are shown on the console.
-#' @param descript      logical: if \code{TRUE} (default), descriptive statistics
-#'                      are shown on the console.
-#' @param effsize       logical: if \code{TRUE}, effect size measure Cohen's d for
-#'                      Welch's two-sample t-test (see \code{\link{cohens.d}}),
-#'                      \eqn{\eta^2} and \eqn{\omega^2} for Welch's ANOVA and
-#'                      Cohen's d for the post hoc tests are shown on the console.
-#' @param weighted      logical: if \code{TRUE}, the weighted pooled standard
-#'                      deviation is used to compute Cohen's d.
-#' @param ref           a numeric value or character string indicating the reference
-#'                      group. The standard deviation of the reference group is
-#'                      used to standardized the mean difference to compute
-#'                      Cohen's d.
-#' @param correct       logical: if \code{TRUE}, correction factor to remove
-#'                      positive bias in small samples is used.
-#' @param plot          logical: if \code{TRUE}, a plot showing error bars for
-#'                      confidence intervals is drawn.
-#' @param point.size    a numeric value indicating the \code{size} aesthetic for
-#'                      the point representing the mean value.
-#' @param adjust        logical: if \code{TRUE} (default), difference-adjustment
-#'                      for the confidence intervals is applied.
-#' @param error.width   a numeric value indicating the horizontal bar width of
-#'                      the error bar.
-#' @param xlab          a character string specifying the labels for the x-axis.
-#' @param ylab          a character string specifying the labels for the y-axis.
-#' @param ylim          a numeric vector of length two specifying limits of the
-#'                      limits of the y-axis.
-#' @param breaks        a numeric vector specifying the points at which tick-marks
-#'                      are drawn at the y-axis.
-#' @param jitter        logical: if \code{TRUE} (default), jittered data points
-#'                      are drawn.
-#' @param jitter.size   a numeric value indicating the \code{size} aesthetic
-#'                      for the jittered data points.
-#' @param jitter.width  a numeric value indicating the amount of horizontal jitter.
-#' @param jitter.height a numeric value indicating the amount of vertical jitter.
-#' @param jitter.alpha  a numeric value indicating the opacity of the jittered
-#'                      data points.
-#' @param title         a character string specifying the text for the title for
-#'                      the plot.
-#' @param subtitle      a character string specifying the text for the subtitle for
-#'                      the plot.
-#' @param digits        an integer value indicating the number of decimal places
-#'                      to be used for displaying descriptive statistics and
-#'                      confidence interval.
-#' @param p.digits      an integer value indicating the number of decimal places
-#'                      to be used for displaying the \emph{p}-value.
-#' @param as.na         a numeric vector indicating user-defined missing values,
-#'                      i.e. these values are converted to \code{NA} before conducting
-#'                      the analysis.
-#' @param write         a character string naming a text file with file extension
-#'                      \code{".txt"} (e.g., \code{"Output.txt"}) for writing the
-#'                      output into a text file.
-#' @param append        logical: if \code{TRUE} (default), output will be appended
-#'                      to an existing text file with extension \code{.txt} specified
-#'                      in \code{write}, if \code{FALSE} existing text file will be
-#'                      overwritten.
-#' @param check         logical: if \code{TRUE} (default), argument specification
-#'                      is checked.
-#' @param output        logical: if \code{TRUE} (default), output is shown on the
-#'                      console.
-#' @param ...           further arguments to be passed to or from methods.
+#' @param formula        a formula of the form \code{y ~ group} where \code{y} is
+#'                       a numeric variable giving the data values and \code{group}
+#'                       a numeric variable, character variable or factor with two
+#'                       or more than two values or factor levels giving the
+#'                       corresponding groups.
+#' @param data           a matrix or data frame containing the variables in the
+#'                       formula \code{formula}.
+#' @param alternative    a character string specifying the alternative hypothesis,
+#'                       must be one of \code{"two.sided"} (default), \code{"greater"}
+#'                       or \code{"less"}. Note that this argument is only used when
+#'                       conducting Welch's two-sample t-test.
+#' @param posthoc        logical: if \code{TRUE}, Games-Howell post hoc test for
+#'                       multiple comparison is conducted when performing Welch's
+#'                       ANOVA.
+#' @param conf.level     a numeric value between 0 and 1 indicating the confidence
+#'                       level of the interval.
+#' @param hypo           logical: if \code{TRUE} (default), null and alternative
+#'                       hypothesis are shown on the console.
+#' @param descript       logical: if \code{TRUE} (default), descriptive statistics
+#'                       are shown on the console.
+#' @param effsize        logical: if \code{TRUE}, effect size measure Cohen's d for
+#'                       Welch's two-sample t-test (see \code{\link{cohens.d}}),
+#'                       \eqn{\eta^2} and \eqn{\omega^2} for Welch's ANOVA and
+#'                       Cohen's d for the post hoc tests are shown on the console.
+#' @param weighted       logical: if \code{TRUE}, the weighted pooled standard
+#'                       deviation is used to compute Cohen's d.
+#' @param ref            a numeric value or character string indicating the reference
+#'                       group. The standard deviation of the reference group is
+#'                       used to standardized the mean difference to compute
+#'                       Cohen's d.
+#' @param correct        logical: if \code{TRUE}, correction factor to remove
+#'                       positive bias in small samples is used.
+#' @param plot           logical: if \code{TRUE}, a plot showing error bars for
+#'                       confidence intervals is drawn.
+#' @param adjust         logical: if \code{TRUE} (default), difference-adjustment
+#'                       for the confidence intervals is applied.
+#' @param point.size     a numeric value indicating the \code{size} aesthetic for
+#'                       the point representing the mean value.
+#' @param errorbar.width a numeric value indicating the horizontal bar width of
+#'                       the error bar.
+#' @param xlab           a character string specifying the labels for the x-axis.
+#' @param ylab           a character string specifying the labels for the y-axis.
+#' @param ylim           a numeric vector of length two specifying limits of the
+#'                       limits of the y-axis.
+#' @param breaks         a numeric vector specifying the points at which tick-marks
+#'                       are drawn at the y-axis.
+#' @param jitter         logical: if \code{TRUE} (default), jittered data points
+#'                       are drawn.
+#' @param jitter.size    a numeric value indicating the \code{size} aesthetic
+#'                       for the jittered data points.
+#' @param jitter.width   a numeric value indicating the amount of horizontal jitter.
+#' @param jitter.height  a numeric value indicating the amount of vertical jitter.
+#' @param jitter.alpha   a numeric value indicating the opacity of the jittered
+#'                       data points.
+#' @param title          a character string specifying the text for the title for
+#'                       the plot.
+#' @param subtitle       a character string specifying the text for the subtitle for
+#'                       the plot.
+#' @param digits         an integer value indicating the number of decimal places
+#'                       to be used for displaying descriptive statistics and
+#'                       confidence interval.
+#' @param p.digits       an integer value indicating the number of decimal places
+#'                       to be used for displaying the \emph{p}-value.
+#' @param as.na          a numeric vector indicating user-defined missing values,
+#'                       i.e. these values are converted to \code{NA} before conducting
+#'                       the analysis.
+#' @param write          a character string naming a text file with file extension
+#'                       \code{".txt"} (e.g., \code{"Output.txt"}) for writing the
+#'                       output into a text file.
+#' @param append         logical: if \code{TRUE} (default), output will be appended
+#'                       to an existing text file with extension \code{.txt} specified
+#'                       in \code{write}, if \code{FALSE} existing text file will be
+#'                       overwritten.
+#' @param check          logical: if \code{TRUE} (default), argument specification
+#'                       is checked.
+#' @param output         logical: if \code{TRUE} (default), output is shown on the
+#'                       console.
+#' @param ...            further arguments to be passed to or from methods.
 #'
 #' @details
 #' \describe{
@@ -113,69 +113,34 @@
 #' @return
 #' Returns an object of class \code{misty.object}, which is a list with following
 #' entries:
-#' \tabular{ll}{
-#' \code{call} \tab function call \cr
-#' \code{type} \tab type of analysis \cr
-#' \code{sample} \tab type of sample, i.e., two- or multiple sample \cr
-#' \code{formula} \tab formula \cr
-#' \code{data} \tab data frame with the outcome and grouping variable \cr
-#' \code{plot} \tab ggplot2 object for plotting the results \cr
-#' \code{args} \tab specification of function arguments \cr
-#' \code{result} \tab list of result table \cr
-#' }
+#' \item{\code{call}}{function call}
+#' \item{\code{type}}{type of analysis}
+#' \item{\code{sample}}{type of sample, i.e., one-, two-, or paired sample}
+#' \item{\code{formula}}{formula}
+#' \item{\code{data}}{data frame with the outcome and grouping variable}
+#' \item{\code{args}}{specification of function arguments}
+#' \item{\code{plot}}{ggplot2 object for plotting the results}
+#' \item{\code{result}}{result table}
 #'
 #' @export
 #'
 #' @examples
-#' dat1 <- data.frame(group1 = c(1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2),
-#'                    group2 = c(1, 1, 1, 1, 2, 2, 2, 2, 3, 3, 3, 3),
-#'                    y = c(3, 1, 4, 2, 5, 3, 2, 3, 6, 6, 3, NA))
-#'
 #' #----------------------------------------------------------------------------
 #' # Two-Sample Design
 #'
 #' # Example 1a: Two-sided two-sample Welch-test
-#' test.welch(y ~ group1, data = dat1)
+#' test.welch(mpg ~ vs, data = mtcars)
 #'
 #' # Example 1b: One-sided two-sample Welch-test
-#' test.welch(y ~ group1, data = dat1, alternative = "greater")
+#' test.welch(mpg ~ vs, data = mtcars, alternative = "greater")
 #'
 #' # Example 1c: Two-sided two-sample Welch-test
 #' # print Cohen's d with weighted pooled SD
-#' test.welch(y ~ group1, data = dat1, effsize = TRUE)
+#' test.welch(mpg ~ vs, data = mtcars, effsize = TRUE)
 #'
 #' # Example 1d: Two-sided two-sample Welch-test
-#' # print Cohen's d with unweighted pooled SD
-#' test.welch(y ~ group1, data = dat1, effsize = TRUE, weighted = FALSE)
-#'
-#' # Example 1e: Two-sided two-sample Welch-test
-#' # print Cohen's d with weighted pooled SD and
-#' # small sample correction factor
-#' test.welch(y ~ group1, data = dat1, effsize = TRUE, correct = TRUE)
-#'
-#' # Example 1f: Two-sided two-sample Welch-test
-#' # print Cohen's d with SD of the reference group 1
-#' test.welch(y ~ group1, data = dat1, effsize = TRUE,
-#'            ref = 1)
-#'
-#' # Example 1g: Two-sided two-sample Welch-test
-#' # print Cohen's d with weighted pooled SD and
-#' # small sample correction factor
-#' test.welch(y ~ group1, data = dat1, effsize = TRUE,
-#'            correct = TRUE)
-#'
-#' # Example 1h: Two-sided two-sample Welch-test
-#' # do not print hypotheses and descriptive statistics,
-#' test.welch(y ~ group1, data = dat1, descript = FALSE, hypo = FALSE)
-#'
-#' # Example 1i: Two-sided two-sample Welch-test
-#' # print descriptive statistics with 3 digits and p-value with 5 digits
-#' test.welch(y ~ group1, data = dat1, digits = 3, p.digits = 5)
-#'
-#' \dontrun{
-#' # Example 1j: Two-sided two-sample Welch-test
 #' # plot results
-#' test.welch(y ~ group1, data = dat1, plot = TRUE)
+#' test.welch(mpg ~ vs, data = mtcars, plot = TRUE)
 #'
 #' # Load ggplot2 package
 #' library(ggplot2)
@@ -183,40 +148,37 @@
 #' # Save plot, ggsave() from the ggplot2 package
 #' ggsave("Two-sample_Welch-test.png", dpi = 600, width = 4, height = 6)
 #'
-#' # Example 1k: Two-sided two-sample Welch-test
+#' # Example 1e: Two-sided two-sample Welch-test
 #' # extract plot
-#' p <- test.welch(y ~ group1, data = dat1, output = FALSE)$plot
+#' p <- test.welch(mpg ~ vs, data = mtcars, output = FALSE)$plot
 #' p
 #'
-#' # Extract data
-#' plotdat <- test.welch(y ~ group1, data = dat1, output = FALSE)$data
-#'
+#' # Example 1f: Two-sided two-sample Welch-test
 #' # Draw plot in line with the default setting of test.welch()
+#'
+#' # Extract data
+#' plotdat <- test.welch(mpg ~ vs, data = mtcars, output = FALSE)$data
+#'
+#' # Draw plot
 #' ggplot(plotdat, aes(factor(group), y)) +
 #'   geom_point(stat = "summary", fun = "mean", size = 4) +
 #'   stat_summary(fun.data = "mean_cl_normal", geom = "errorbar", width = 0.20) +
 #'   scale_x_discrete(name = NULL) +
 #'   labs(subtitle = "Two-Sided 95% Confidence Interval") +
 #'   theme_bw() + theme(plot.subtitle = element_text(hjust = 0.5))
-#' }
+#'
 #' #----------------------------------------------------------------------------
 #' # Multiple-Sample Design
 #'
 #' # Example 2a: Welch's ANOVA
-#' test.welch(y ~ group2, data = dat1)
+#' test.welch(mpg ~ gear, data = mtcars)
 #'
 #' # Example 2b: Welch's ANOVA
 #' # print eta-squared and omega-squared
-#' test.welch(y ~ group2, data = dat1, effsize = TRUE)
+#' test.welch(mpg ~ gear, data = mtcars, effsize = TRUE)
 #'
-#' # Example 2c: Welch's ANOVA
-#' # do not print hypotheses and descriptive statistics,
-#' test.welch(y ~ group2, data = dat1, descript = FALSE, hypo = FALSE)
-#'
-#' \dontrun{
-#' # Example 2d: Welch's ANOVA
-#' # plot results
-#' test.welch(y ~ group2, data = dat1, plot = TRUE)
+#' # Example 2c: Welch's ANOVA, plot results
+#' test.welch(mpg ~ gear, data = mtcars, plot = TRUE)
 #'
 #' # Load ggplot2 package
 #' library(ggplot2)
@@ -226,29 +188,31 @@
 #'
 #' # Example 2e: Welch's ANOVA
 #' # extract plot
-#' p <- test.welch(y ~ group2, data = dat1, output = FALSE)$plot
+#' p <- test.welch(mpg ~ gear, data = mtcars, output = FALSE)$plot
 #' p
 #'
-#' # Extract data
-#' plotdat <- test.welch(y ~ group2, data = dat1, output = FALSE)$data
-#'
+#' # Example 2e: Welch's ANOVA
 #' # Draw plot in line with the default setting of test.welch()
+#'
+#' # Extract data
+#' plotdat <- test.welch(mpg ~ gear, data = mtcars, output = FALSE)$data
+#'
+#' # Draw plot
 #' ggplot(plotdat, aes(group, y)) +
 #'   geom_point(stat = "summary", fun = "mean", size = 4) +
 #'   stat_summary(fun.data = "mean_cl_normal", geom = "errorbar", width = 0.20) +
 #'   scale_x_discrete(name = NULL) +
 #'   labs(subtitle = "Two-Sided 95% Confidence Interval") +
 #'   theme_bw() + theme(plot.subtitle = element_text(hjust = 0.5))
-#' }
 test.welch <- function(formula, data, alternative = c("two.sided", "less", "greater"),
                        posthoc = FALSE, conf.level = 0.95, hypo = TRUE, descript = TRUE,
                        effsize = FALSE, weighted = FALSE, ref = NULL, correct = FALSE,
-                       plot = FALSE, point.size = 4, adjust = TRUE, error.width = 0.1,
+                       plot = FALSE, adjust = TRUE, point.size = 4, errorbar.width = 0.1,
                        xlab = NULL, ylab = NULL, ylim = NULL, breaks = ggplot2::waiver(),
                        jitter = TRUE, jitter.size = 1.25, jitter.width = 0.05,
                        jitter.height = 0, jitter.alpha = 0.1,
                        title = "",  subtitle = "Confidence Interval",
-                       digits = 2, p.digits = 4, as.na = NULL, write = NULL, append = TRUE,
+                       digits = 2, p.digits = 3, as.na = NULL, write = NULL, append = TRUE,
                        check = TRUE, output = TRUE, ...) {
 
   #_____________________________________________________________________________
@@ -280,20 +244,21 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
   #
   # Input Check ----------------------------------------------------------------
 
-  # Check input 'check'
-  if (isTRUE(!is.logical(check))) { stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE) }
-
-  # ggplot2 package
-  if (isTRUE(!nzchar(system.file(package = "ggplot2"))))  { warning("Package \"ggplot2\" is needed for drawing a bar chart, please install the package.", call. = FALSE) }
+  # Check inputs
+  .check.input(logical = c("hypo", "descript", "effsize", "weighted", "correct", "plot", "jitter", "append", "output"),
+               numeric = list(point.size = 1L, errorbar.width = 1L, jitter.size = 1L, jitter.width = 1L, jitter.height = 1L, jitter.alpha = 1L, ylim = 2L),
+               character = list(xlab = 1L, ylab = 1L, title = 1L, subtitle = 1L),
+               args = c("conf.level", "digits", "p.digits", "write1"),
+               package = "ggplot2", envir = environment(), input.check = check)
 
+  # Additional checks
   if (isTRUE(check)) {
 
     # Check if variables are in the data
     var.data <- !var.formula %in% colnames(data)
     if (isTRUE(any(var.data))) {
 
-      stop(paste0("Variables specified in the the formula were not found in 'data': ",
-                  paste(var.formula[which(var.data)], collapse = ", ")), call. = FALSE)
+      stop(paste0("Variables specified in the the formula were not found in 'data': ", paste(var.formula[which(var.data)], collapse = ", ")), call. = FALSE)
 
     }
 
@@ -303,51 +268,6 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
     # Check if input 'formula' has only one outcome variable
     if (isTRUE(length(y.var) != 1L)) { stop("Please specify a formula with only one outcome variable.", call. = FALSE) }
 
-    # Check input 'descript'
-    if (isTRUE(!is.logical(descript))) { stop("Please specify TRUE or FALSE for the argument 'descript'.", call. = FALSE) }
-
-    # Check input 'alternative'
-    if (isTRUE(!all(alternative %in%  c("two.sided", "less", "greater")))) { stop("Character string in the argument 'alternative' does not match with \"two.sided\", \"less\", or \"greater\".", call. = FALSE) }
-
-    # Check input 'conf.level'
-    if (isTRUE(conf.level >= 1L || conf.level <= 0L)) { stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.", call. = FALSE) }
-
-    # Check input 'effsize'
-    if (isTRUE(!is.logical(effsize))) { stop("Please specify TRUE or FALSE for the argument 'effsize'.", call. = FALSE) }
-
-    # Check input 'weighted'
-    if (isTRUE(!is.logical(weighted))) { stop("Please specify TRUE or FALSE for the argument 'weighted'.", call. = FALSE) }
-
-    # Check input 'correct'
-    if (isTRUE(!is.logical(correct))) { stop("Please specify TRUE or FALSE for the argument 'correct'.", call. = FALSE) }
-
-    # Check input 'hypo'
-    if (isTRUE(!is.logical(hypo))) { stop("Please specify TRUE or FALSE for the argument 'hypo'.", call. = FALSE) }
-
-    # Check input 'descript'
-    if (isTRUE(!is.logical(descript))) { stop("Please specify TRUE or FALSE for the argument 'descript'.", call. = FALSE) }
-
-    # Check input 'plot'
-    if (isTRUE(!is.logical(plot))) { stop("Please specify TRUE or FALSE for the argument 'plot'.", call. = FALSE) }
-
-    # Check input 'jitter'
-    if (isTRUE(!is.logical(jitter))) { stop("Please specify TRUE or FALSE for the argument 'jitter'.", call. = FALSE) }
-
-    # Check input 'digits'
-    if (isTRUE(digits %% 1L != 0L || digits < 0L)) { stop("Please specify a positive integer number for the argument 'digits'.", call. = FALSE) }
-
-    # Check input 'p.digits'
-    if (isTRUE(p.digits %% 1L != 0L || p.digits < 0L)) { stop("Please specify a positive integer number for the argument 'p.digits'.", call. = FALSE) }
-
-    # Check input 'write'
-    if (isTRUE(!is.null(write) && substr(write, nchar(write) - 3L, nchar(write)) != ".txt")) { stop("Please specify a character string with file extenstion '.txt' for the argument 'write'.") }
-
-    # Check input 'append'
-    if (isTRUE(!is.logical(append))) { stop("Please specify TRUE or FALSE for the argument 'append'.", call. = FALSE) }
-
-    # Check input 'output'
-    if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
-
   }
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -424,7 +344,7 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
     #...................
     ### Descriptive statistics ####
 
-    ci <- misty::ci.mean(y, group = group, adjust = adjust, output = FALSE)$result[, -c(2L, 5L)]
+    ci <- misty::ci.mean(y, group = group, adjust = adjust, output = FALSE)$result[, c("group", "n", "nNA", "m", "low", "upp", "sd", "skew", "kurt")]
 
     #...................
     ### ANOVA table ####
@@ -513,8 +433,7 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
       # Drop factor levels
       data.temp[, "group"] <- droplevels(data.temp[, "group"], except = c(combs[1L, x], combs[2L, x]))
 
-      cohen <- misty::cohens.d(y ~ group, data = data.temp, weighted = weighted, correct = correct, conf.level = conf.level,
-                               check = FALSE, output = FALSE)$result
+      cohen <- misty::cohens.d(y ~ group, data = data.temp, weighted = weighted, correct = correct, conf.level = conf.level, check = FALSE, output = FALSE)$result
 
       ###
       # Collect results
@@ -564,7 +483,7 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
   if (isTRUE(jitter)) { p <- p + ggplot2::geom_jitter(alpha = jitter.alpha, width = jitter.width, height = jitter.height, size = jitter.size) }
 
   p <- p + ggplot2::geom_point(data = plot.ci, ggplot2::aes(group, m), stat = "identity", size = point.size) +
-         ggplot2::geom_errorbar(data = plot.ci, ggplot2::aes(group, m, ymin = low, ymax = upp), width = error.width) +
+         ggplot2::geom_errorbar(data = plot.ci, ggplot2::aes(group, m, ymin = low, ymax = upp), width = errorbar.width) +
          ggplot2::scale_x_discrete(name = xlab) +
          ggplot2::scale_y_continuous(name = ylab, limits = ylim, breaks = breaks) +
          ggplot2::theme_bw() +
@@ -584,19 +503,18 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
   object <- list(call = match.call(),
                  type = "test.welch",
                  sample = sample,
-                 data = data.frame(y, group, stringsAsFactors = FALSE),
+                 data = data.frame(y, group),
                  formula = formula,
-                 plot = p,
                  args = list(alternative = alternative, posthoc = posthoc,
                              conf.level = conf.level, hypo = hypo, descript = descript,
                              effsize = effsize, weighted = weighted, ref = ref, correct = correct,
-                             plot = plot, point.size = point.size, error.width = error.width,
+                             plot = plot, adjust = adjust, point.size = point.size, errorbar.width = errorbar.width,
                              xlab = xlab, ylab = ylab, ylim = ylim, breaks = breaks,
                              jitter = jitter, jitter.size = jitter.size, jitter.width = jitter.width,
                              jitter.height = jitter.height, jitter.alpha = jitter.alpha,
                              title = title, subtitle = subtitle, digits = digits, p.digits = p.digits,
                              as.na = as.na, check = check, output = output),
-                 result = result)
+                 plot = p, result = result)
 
   class(object) <- "misty.object"
 
@@ -631,3 +549,5 @@ test.welch <- function(formula, data, alternative = c("two.sided", "less", "grea
   return(invisible(object))
 
 }
+
+#_______________________________________________________________________________
